pub struct ArchiveAccessorStreamDiagnosticsToSocketRequest {
pub stream_parameters: StreamParameters,
pub stream: Socket,
}Fields
stream_parameters: StreamParametersstream: SocketTrait Implementations
Sourceimpl Decode<ArchiveAccessorStreamDiagnosticsToSocketRequest, FDomainResourceDialect> for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl Decode<ArchiveAccessorStreamDiagnosticsToSocketRequest, FDomainResourceDialect> for ArchiveAccessorStreamDiagnosticsToSocketRequest
Sourceimpl Encode<ArchiveAccessorStreamDiagnosticsToSocketRequest, FDomainResourceDialect> for &mut ArchiveAccessorStreamDiagnosticsToSocketRequest
impl Encode<ArchiveAccessorStreamDiagnosticsToSocketRequest, FDomainResourceDialect> for &mut ArchiveAccessorStreamDiagnosticsToSocketRequest
Sourceimpl<T0: Encode<StreamParameters, FDomainResourceDialect>, T1: Encode<HandleType<Socket, { _ }, 16392>, FDomainResourceDialect>> Encode<ArchiveAccessorStreamDiagnosticsToSocketRequest, FDomainResourceDialect> for (T0, T1)
impl<T0: Encode<StreamParameters, FDomainResourceDialect>, T1: Encode<HandleType<Socket, { _ }, 16392>, FDomainResourceDialect>> Encode<ArchiveAccessorStreamDiagnosticsToSocketRequest, FDomainResourceDialect> for (T0, T1)
Sourceimpl ResourceTypeMarker for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl ResourceTypeMarker for ArchiveAccessorStreamDiagnosticsToSocketRequest
Sourcetype Borrowed<'a> = &'a mut ArchiveAccessorStreamDiagnosticsToSocketRequest
type Borrowed<'a> = &'a mut ArchiveAccessorStreamDiagnosticsToSocketRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<FDomainResourceDialect> for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl StructuralPartialEq for ArchiveAccessorStreamDiagnosticsToSocketRequest
Sourceimpl TypeMarker for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl TypeMarker for ArchiveAccessorStreamDiagnosticsToSocketRequest
Sourcetype Owned = ArchiveAccessorStreamDiagnosticsToSocketRequest
type Owned = ArchiveAccessorStreamDiagnosticsToSocketRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl !RefUnwindSafe for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl !UnwindSafe for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl Freeze for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl Send for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl Sync for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl Unpin for ArchiveAccessorStreamDiagnosticsToSocketRequest
impl UnsafeUnpin for ArchiveAccessorStreamDiagnosticsToSocketRequest